# -*- coding: utf8 -*-
# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from tencentcloud.common.abstract_model import AbstractModel


class BunkZone(AbstractModel):
    """点位包含铺位信息

    """

    def __init__(self):
        """
        :param ZoneId: 点位ID
        :type ZoneId: int
        :param ZoneName: 点位名称
        :type ZoneName: str
        :param BunkCodes: 铺位编码
        :type BunkCodes: str
        """
        self.ZoneId = None
        self.ZoneName = None
        self.BunkCodes = None


    def _deserialize(self, params):
        self.ZoneId = params.get("ZoneId")
        self.ZoneName = params.get("ZoneName")
        self.BunkCodes = params.get("BunkCodes")


class CameraConfig(AbstractModel):
    """摄像头配置信息

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param FloorId: 楼层ID
        :type FloorId: int
        :param CameraId: 摄像头ID
        :type CameraId: int
        :param CameraIp: 摄像头IP
        :type CameraIp: str
        :param CameraMac: 摄像头Mac
        :type CameraMac: str
        :param CameraType: 摄像头类型:
1: 码流机
2: AI相机
        :type CameraType: int
        :param CameraFeature: 摄像头功能:
1: 人脸
2: 人体
        :type CameraFeature: int
        :param CameraState: 摄像头是否启用:
0: 下线
1: 启用
        :type CameraState: int
        :param ZoneId: 点位ID
        :type ZoneId: int
        :param ZoneType: 点位类型:
1: 场门
3: 层门
5: 特殊区域
7: 门店
8: 补位
10: 开放式门店
11: 品类区
12: 公共区
        :type ZoneType: int
        :param Config: 配置
        :type Config: :class:`tencentcloud.ump.v20200918.models.Config`
        :param Width: 宽
        :type Width: int
        :param Height: 高
        :type Height: int
        """
        self.GroupCode = None
        self.MallId = None
        self.FloorId = None
        self.CameraId = None
        self.CameraIp = None
        self.CameraMac = None
        self.CameraType = None
        self.CameraFeature = None
        self.CameraState = None
        self.ZoneId = None
        self.ZoneType = None
        self.Config = None
        self.Width = None
        self.Height = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        self.FloorId = params.get("FloorId")
        self.CameraId = params.get("CameraId")
        self.CameraIp = params.get("CameraIp")
        self.CameraMac = params.get("CameraMac")
        self.CameraType = params.get("CameraType")
        self.CameraFeature = params.get("CameraFeature")
        self.CameraState = params.get("CameraState")
        self.ZoneId = params.get("ZoneId")
        self.ZoneType = params.get("ZoneType")
        if params.get("Config") is not None:
            self.Config = Config()
            self.Config._deserialize(params.get("Config"))
        self.Width = params.get("Width")
        self.Height = params.get("Height")


class CameraState(AbstractModel):
    """用于场内上报当前相机的状态

    """

    def __init__(self):
        """
        :param CameraId: 相机ID
        :type CameraId: int
        :param State: 相机状态:
10: 初始化
11: 未知状态
12: 网络异常
13: 未授权
14: 相机App异常
15: 相机取流异常
16: 状态正常
        :type State: int
        """
        self.CameraId = None
        self.State = None


    def _deserialize(self, params):
        self.CameraId = params.get("CameraId")
        self.State = params.get("State")


class CameraZones(AbstractModel):
    """摄像头包含简单的点位信息

    """

    def __init__(self):
        """
        :param CameraId: 摄像头ID
        :type CameraId: int
        :param CameraName: 摄像头名称
        :type CameraName: str
        :param CameraFeature: 摄像头功能:
1: 人脸
2: 人体
        :type CameraFeature: int
        :param CameraIp: 摄像头IP
        :type CameraIp: str
        :param CameraState: 摄像头状态:
0: 异常 (不再使用)
1: 正常 (不再使用)
10: 初始化
11: 未知状态 (因服务内部错误产生)
12: 网络异常
13: 未授权
14: 相机App异常
15: 相机取流异常
16: 正常
        :type CameraState: int
        :param Zones: 点位列表
        :type Zones: list of BunkZone
        :param Pixel: 像素:
130W(1280*960)
200W(1920*1080)
400W(2560*1440)
        :type Pixel: str
        :param RTSP: 相机Rtsp地址
注意：此字段可能返回 null，表示取不到有效值。
        :type RTSP: str
        """
        self.CameraId = None
        self.CameraName = None
        self.CameraFeature = None
        self.CameraIp = None
        self.CameraState = None
        self.Zones = None
        self.Pixel = None
        self.RTSP = None


    def _deserialize(self, params):
        self.CameraId = params.get("CameraId")
        self.CameraName = params.get("CameraName")
        self.CameraFeature = params.get("CameraFeature")
        self.CameraIp = params.get("CameraIp")
        self.CameraState = params.get("CameraState")
        if params.get("Zones") is not None:
            self.Zones = []
            for item in params.get("Zones"):
                obj = BunkZone()
                obj._deserialize(item)
                self.Zones.append(obj)
        self.Pixel = params.get("Pixel")
        self.RTSP = params.get("RTSP")


class Config(AbstractModel):
    """摄像头配置

    """

    def __init__(self):
        """
        :param CameraProducer: 摄像头厂商:
H: 海康
D: 大华
Y: 英飞拓
L: 联纵
        :type CameraProducer: str
        :param RTSP: rtsp 地址
        :type RTSP: str
        :param Fps: 摄像头帧率
        :type Fps: int
        :param DecodeFps: 解码帧率
        :type DecodeFps: int
        :param PassengerFlow: 是否做客流计算:
0: 否
1: 是
        :type PassengerFlow: int
        :param FaceExpose: 是否打开人脸曝光:
0: 关闭
1: 开启
        :type FaceExpose: int
        :param MallArea: 门线标注
        :type MallArea: list of Point
        :param ShopArea: 店门标注
        :type ShopArea: list of Point
        :param TrackAreas: 检测区标注
        :type TrackAreas: list of Polygon
        :param Zones: 点位列表（品类区）
        :type Zones: list of ZoneArea
        """
        self.CameraProducer = None
        self.RTSP = None
        self.Fps = None
        self.DecodeFps = None
        self.PassengerFlow = None
        self.FaceExpose = None
        self.MallArea = None
        self.ShopArea = None
        self.TrackAreas = None
        self.Zones = None


    def _deserialize(self, params):
        self.CameraProducer = params.get("CameraProducer")
        self.RTSP = params.get("RTSP")
        self.Fps = params.get("Fps")
        self.DecodeFps = params.get("DecodeFps")
        self.PassengerFlow = params.get("PassengerFlow")
        self.FaceExpose = params.get("FaceExpose")
        if params.get("MallArea") is not None:
            self.MallArea = []
            for item in params.get("MallArea"):
                obj = Point()
                obj._deserialize(item)
                self.MallArea.append(obj)
        if params.get("ShopArea") is not None:
            self.ShopArea = []
            for item in params.get("ShopArea"):
                obj = Point()
                obj._deserialize(item)
                self.ShopArea.append(obj)
        if params.get("TrackAreas") is not None:
            self.TrackAreas = []
            for item in params.get("TrackAreas"):
                obj = Polygon()
                obj._deserialize(item)
                self.TrackAreas.append(obj)
        if params.get("Zones") is not None:
            self.Zones = []
            for item in params.get("Zones"):
                obj = ZoneArea()
                obj._deserialize(item)
                self.Zones.append(obj)


class CreateCameraAlertAlert(AbstractModel):
    """告警信息

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param CameraId: 相机ID
        :type CameraId: int
        :param CaptureTime: 时间戳,ms,默认为告警请求到达时间
        :type CaptureTime: int
        :param Image: 图片base64编码
        :type Image: str
        :param MoveAlert: 移动告警
        :type MoveAlert: :class:`tencentcloud.ump.v20200918.models.CreateCameraAlertsMoveAlert`
        :param CoverAlert: 遮挡告警
        :type CoverAlert: :class:`tencentcloud.ump.v20200918.models.CreateCameraAlertsCoverAlert`
        """
        self.GroupCode = None
        self.MallId = None
        self.CameraId = None
        self.CaptureTime = None
        self.Image = None
        self.MoveAlert = None
        self.CoverAlert = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        self.CameraId = params.get("CameraId")
        self.CaptureTime = params.get("CaptureTime")
        self.Image = params.get("Image")
        if params.get("MoveAlert") is not None:
            self.MoveAlert = CreateCameraAlertsMoveAlert()
            self.MoveAlert._deserialize(params.get("MoveAlert"))
        if params.get("CoverAlert") is not None:
            self.CoverAlert = CreateCameraAlertsCoverAlert()
            self.CoverAlert._deserialize(params.get("CoverAlert"))


class CreateCameraAlertsCoverAlert(AbstractModel):
    """遮挡告警

    """

    def __init__(self):
        """
        :param Cover: 是否遮挡
        :type Cover: bool
        :param CoverConfidence: 是否移动置信度
        :type CoverConfidence: float
        """
        self.Cover = None
        self.CoverConfidence = None


    def _deserialize(self, params):
        self.Cover = params.get("Cover")
        self.CoverConfidence = params.get("CoverConfidence")


class CreateCameraAlertsMoveAlert(AbstractModel):
    """移动告警

    """

    def __init__(self):
        """
        :param Move: 是否移动
        :type Move: bool
        :param MoveConfidence: 是否移动置信度
        :type MoveConfidence: float
        """
        self.Move = None
        self.MoveConfidence = None


    def _deserialize(self, params):
        self.Move = params.get("Move")
        self.MoveConfidence = params.get("MoveConfidence")


class CreateCameraAlertsRequest(AbstractModel):
    """CreateCameraAlerts请求参数结构体

    """

    def __init__(self):
        """
        :param Alerts: 告警信息列表
        :type Alerts: list of CreateCameraAlertAlert
        """
        self.Alerts = None


    def _deserialize(self, params):
        if params.get("Alerts") is not None:
            self.Alerts = []
            for item in params.get("Alerts"):
                obj = CreateCameraAlertAlert()
                obj._deserialize(item)
                self.Alerts.append(obj)


class CreateCameraAlertsResponse(AbstractModel):
    """CreateCameraAlerts返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class CreateCameraStateRequest(AbstractModel):
    """CreateCameraState请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param CameraStates: 场内所有相机的状态值
        :type CameraStates: list of CameraState
        """
        self.GroupCode = None
        self.MallId = None
        self.CameraStates = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        if params.get("CameraStates") is not None:
            self.CameraStates = []
            for item in params.get("CameraStates"):
                obj = CameraState()
                obj._deserialize(item)
                self.CameraStates.append(obj)


class CreateCameraStateResponse(AbstractModel):
    """CreateCameraState返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class CreateCaptureRequest(AbstractModel):
    """CreateCapture请求参数结构体

    """

    def __init__(self):
        """
        :param Data: 原始抓拍报文
        :type Data: str
        """
        self.Data = None


    def _deserialize(self, params):
        self.Data = params.get("Data")


class CreateCaptureResponse(AbstractModel):
    """CreateCapture返回参数结构体

    """

    def __init__(self):
        """
        :param RspData: 原始应答报文
注意：此字段可能返回 null，表示取不到有效值。
        :type RspData: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RspData = None
        self.RequestId = None


    def _deserialize(self, params):
        self.RspData = params.get("RspData")
        self.RequestId = params.get("RequestId")


class CreateMultiBizAlertRequest(AbstractModel):
    """CreateMultiBizAlert请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param ZoneId: 点位ID
        :type ZoneId: int
        :param CameraId: 摄像头ID
        :type CameraId: int
        :param CaptureTime: 时间戳，毫秒
        :type CaptureTime: int
        :param State: 状态: 
1: 侵占
2: 消失
3: 即侵占又消失
        :type State: int
        :param Image: 图片base64字符串
        :type Image: str
        :param Warnings: 告警列表
        :type Warnings: list of MultiBizWarning
        """
        self.GroupCode = None
        self.MallId = None
        self.ZoneId = None
        self.CameraId = None
        self.CaptureTime = None
        self.State = None
        self.Image = None
        self.Warnings = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        self.ZoneId = params.get("ZoneId")
        self.CameraId = params.get("CameraId")
        self.CaptureTime = params.get("CaptureTime")
        self.State = params.get("State")
        self.Image = params.get("Image")
        if params.get("Warnings") is not None:
            self.Warnings = []
            for item in params.get("Warnings"):
                obj = MultiBizWarning()
                obj._deserialize(item)
                self.Warnings.append(obj)


class CreateMultiBizAlertResponse(AbstractModel):
    """CreateMultiBizAlert返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class CreateProgramStateRequest(AbstractModel):
    """CreateProgramState请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param ProgramStateItems: 进程监控信息列表
        :type ProgramStateItems: list of ProgramStateItem
        :param MallId: 商场ID
        :type MallId: int
        """
        self.GroupCode = None
        self.ProgramStateItems = None
        self.MallId = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        if params.get("ProgramStateItems") is not None:
            self.ProgramStateItems = []
            for item in params.get("ProgramStateItems"):
                obj = ProgramStateItem()
                obj._deserialize(item)
                self.ProgramStateItems.append(obj)
        self.MallId = params.get("MallId")


class CreateProgramStateResponse(AbstractModel):
    """CreateProgramState返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class CreateServerStateRequest(AbstractModel):
    """CreateServerState请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param ServerStateItems: 服务器监控信息列表
        :type ServerStateItems: list of ServerStateItem
        :param MallId: 商场ID
        :type MallId: int
        :param ReportTime: 服务器监控信息上报时间戳，单位毫秒
        :type ReportTime: int
        """
        self.GroupCode = None
        self.ServerStateItems = None
        self.MallId = None
        self.ReportTime = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        if params.get("ServerStateItems") is not None:
            self.ServerStateItems = []
            for item in params.get("ServerStateItems"):
                obj = ServerStateItem()
                obj._deserialize(item)
                self.ServerStateItems.append(obj)
        self.MallId = params.get("MallId")
        self.ReportTime = params.get("ReportTime")


class CreateServerStateResponse(AbstractModel):
    """CreateServerState返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class DeleteMultiBizAlertRequest(AbstractModel):
    """DeleteMultiBizAlert请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param ZoneId: 点位ID
        :type ZoneId: int
        :param CameraId: 摄像头ID
        :type CameraId: int
        :param ActionType: 消警动作:
1: 误报
2: 正报合规
3: 正报不合规，整改完成
        :type ActionType: int
        :param Image: 图片base64字符串
        :type Image: str
        """
        self.GroupCode = None
        self.MallId = None
        self.ZoneId = None
        self.CameraId = None
        self.ActionType = None
        self.Image = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        self.ZoneId = params.get("ZoneId")
        self.CameraId = params.get("CameraId")
        self.ActionType = params.get("ActionType")
        self.Image = params.get("Image")


class DeleteMultiBizAlertResponse(AbstractModel):
    """DeleteMultiBizAlert返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class DeleteTaskRequest(AbstractModel):
    """DeleteTask请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param TaskId: 任务ID
        :type TaskId: int
        """
        self.GroupCode = None
        self.MallId = None
        self.TaskId = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        self.TaskId = params.get("TaskId")


class DeleteTaskResponse(AbstractModel):
    """DeleteTask返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class DescribeCamerasRequest(AbstractModel):
    """DescribeCameras请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        """
        self.GroupCode = None
        self.MallId = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")


class DescribeCamerasResponse(AbstractModel):
    """DescribeCameras返回参数结构体

    """

    def __init__(self):
        """
        :param Cameras: 摄像头列表
        :type Cameras: list of CameraZones
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Cameras = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Cameras") is not None:
            self.Cameras = []
            for item in params.get("Cameras"):
                obj = CameraZones()
                obj._deserialize(item)
                self.Cameras.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeConfigRequest(AbstractModel):
    """DescribeConfig请求参数结构体

    """

    def __init__(self):
        """
        :param SessionId: 会话ID
        :type SessionId: str
        :param CameraSign: 摄像头签名
        :type CameraSign: str
        :param CameraAppId: 摄像头app id
        :type CameraAppId: str
        :param CameraTimestamp: 摄像头时间戳，毫秒
        :type CameraTimestamp: int
        :param ServerMac: MAC地址，字母大写
        :type ServerMac: str
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        """
        self.SessionId = None
        self.CameraSign = None
        self.CameraAppId = None
        self.CameraTimestamp = None
        self.ServerMac = None
        self.GroupCode = None
        self.MallId = None


    def _deserialize(self, params):
        self.SessionId = params.get("SessionId")
        self.CameraSign = params.get("CameraSign")
        self.CameraAppId = params.get("CameraAppId")
        self.CameraTimestamp = params.get("CameraTimestamp")
        self.ServerMac = params.get("ServerMac")
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")


class DescribeConfigResponse(AbstractModel):
    """DescribeConfig返回参数结构体

    """

    def __init__(self):
        """
        :param SessionId: 会话ID
        :type SessionId: str
        :param Version: 配置版本号
        :type Version: int
        :param Cameras: 摄像头列表
        :type Cameras: list of CameraConfig
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.SessionId = None
        self.Version = None
        self.Cameras = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SessionId = params.get("SessionId")
        self.Version = params.get("Version")
        if params.get("Cameras") is not None:
            self.Cameras = []
            for item in params.get("Cameras"):
                obj = CameraConfig()
                obj._deserialize(item)
                self.Cameras.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeImageRequest(AbstractModel):
    """DescribeImage请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param CameraId: 摄像头ID
        :type CameraId: int
        """
        self.GroupCode = None
        self.MallId = None
        self.CameraId = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        self.CameraId = params.get("CameraId")


class DescribeImageResponse(AbstractModel):
    """DescribeImage返回参数结构体

    """

    def __init__(self):
        """
        :param ImageUrl: cos 临时 url，异步上传图片，client需要轮询
        :type ImageUrl: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.ImageUrl = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ImageUrl = params.get("ImageUrl")
        self.RequestId = params.get("RequestId")


class DescribeMultiBizBaseImageRequest(AbstractModel):
    """DescribeMultiBizBaseImage请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param CameraId: 摄像头ID
        :type CameraId: int
        :param ZoneId: 点位ID
        :type ZoneId: int
        """
        self.GroupCode = None
        self.MallId = None
        self.CameraId = None
        self.ZoneId = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        self.CameraId = params.get("CameraId")
        self.ZoneId = params.get("ZoneId")


class DescribeMultiBizBaseImageResponse(AbstractModel):
    """DescribeMultiBizBaseImage返回参数结构体

    """

    def __init__(self):
        """
        :param ImageUrl: cos 临时 url
        :type ImageUrl: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.ImageUrl = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ImageUrl = params.get("ImageUrl")
        self.RequestId = params.get("RequestId")


class DescribeTasksRequest(AbstractModel):
    """DescribeTasks请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param TaskType: 任务类型:
1: 底图拉取
        :type TaskType: int
        """
        self.GroupCode = None
        self.MallId = None
        self.TaskType = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        self.TaskType = params.get("TaskType")


class DescribeTasksResponse(AbstractModel):
    """DescribeTasks返回参数结构体

    """

    def __init__(self):
        """
        :param Tasks: 任务列表
        :type Tasks: list of Task
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Tasks = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Tasks") is not None:
            self.Tasks = []
            for item in params.get("Tasks"):
                obj = Task()
                obj._deserialize(item)
                self.Tasks.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeZonesRequest(AbstractModel):
    """DescribeZones请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        """
        self.GroupCode = None
        self.MallId = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")


class DescribeZonesResponse(AbstractModel):
    """DescribeZones返回参数结构体

    """

    def __init__(self):
        """
        :param Zones: 点位列表
        :type Zones: list of ZoneConfig
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Zones = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Zones") is not None:
            self.Zones = []
            for item in params.get("Zones"):
                obj = ZoneConfig()
                obj._deserialize(item)
                self.Zones.append(obj)
        self.RequestId = params.get("RequestId")


class DiskInfo(AbstractModel):
    """硬盘监控信息

    """

    def __init__(self):
        """
        :param DiskName: 硬盘名字
        :type DiskName: str
        :param Usage: 硬盘使用率
        :type Usage: float
        """
        self.DiskName = None
        self.Usage = None


    def _deserialize(self, params):
        self.DiskName = params.get("DiskName")
        self.Usage = params.get("Usage")


class ModifyMultiBizConfigRequest(AbstractModel):
    """ModifyMultiBizConfig请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param ZoneId: 点位ID
        :type ZoneId: int
        :param CameraId: 摄像头ID
        :type CameraId: int
        :param MonitoringAreas: 监控区域
        :type MonitoringAreas: list of Polygon
        """
        self.GroupCode = None
        self.MallId = None
        self.ZoneId = None
        self.CameraId = None
        self.MonitoringAreas = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        self.ZoneId = params.get("ZoneId")
        self.CameraId = params.get("CameraId")
        if params.get("MonitoringAreas") is not None:
            self.MonitoringAreas = []
            for item in params.get("MonitoringAreas"):
                obj = Polygon()
                obj._deserialize(item)
                self.MonitoringAreas.append(obj)


class ModifyMultiBizConfigResponse(AbstractModel):
    """ModifyMultiBizConfig返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class MultiBizWarning(AbstractModel):
    """多经点位告警

    """

    def __init__(self):
        """
        :param Id: 编号
        :type Id: int
        :param MonitoringArea: 监控区域
        :type MonitoringArea: list of Point
        :param WarningInfos: 告警列表
        :type WarningInfos: list of MultiBizWarningInfo
        """
        self.Id = None
        self.MonitoringArea = None
        self.WarningInfos = None


    def _deserialize(self, params):
        self.Id = params.get("Id")
        if params.get("MonitoringArea") is not None:
            self.MonitoringArea = []
            for item in params.get("MonitoringArea"):
                obj = Point()
                obj._deserialize(item)
                self.MonitoringArea.append(obj)
        if params.get("WarningInfos") is not None:
            self.WarningInfos = []
            for item in params.get("WarningInfos"):
                obj = MultiBizWarningInfo()
                obj._deserialize(item)
                self.WarningInfos.append(obj)


class MultiBizWarningInfo(AbstractModel):
    """多经点位告警信息

    """

    def __init__(self):
        """
        :param WarningType: 告警类型：
0: 无变化
1: 侵占
2: 消失
        :type WarningType: int
        :param WarningAreaSize: 告警侵占或消失面积
        :type WarningAreaSize: float
        :param WarningLocation: 告警侵占或消失坐标
        :type WarningLocation: :class:`tencentcloud.ump.v20200918.models.Point`
        :param WarningAreaContour: 告警侵占或消失轮廓
        :type WarningAreaContour: list of Point
        """
        self.WarningType = None
        self.WarningAreaSize = None
        self.WarningLocation = None
        self.WarningAreaContour = None


    def _deserialize(self, params):
        self.WarningType = params.get("WarningType")
        self.WarningAreaSize = params.get("WarningAreaSize")
        if params.get("WarningLocation") is not None:
            self.WarningLocation = Point()
            self.WarningLocation._deserialize(params.get("WarningLocation"))
        if params.get("WarningAreaContour") is not None:
            self.WarningAreaContour = []
            for item in params.get("WarningAreaContour"):
                obj = Point()
                obj._deserialize(item)
                self.WarningAreaContour.append(obj)


class Point(AbstractModel):
    """点

    """

    def __init__(self):
        """
        :param X: X坐标
        :type X: int
        :param Y: Y坐标
        :type Y: int
        """
        self.X = None
        self.Y = None


    def _deserialize(self, params):
        self.X = params.get("X")
        self.Y = params.get("Y")


class Polygon(AbstractModel):
    """多边形

    """

    def __init__(self):
        """
        :param Points: 标注列表
        :type Points: list of Point
        """
        self.Points = None


    def _deserialize(self, params):
        if params.get("Points") is not None:
            self.Points = []
            for item in params.get("Points"):
                obj = Point()
                obj._deserialize(item)
                self.Points.append(obj)


class ProgramStateItem(AbstractModel):
    """进程状态监控项

    """

    def __init__(self):
        """
        :param ServerIp: 服务器IP
        :type ServerIp: str
        :param ProgramName: 进程名字
        :type ProgramName: str
        :param OnlineCount: 在线个数
        :type OnlineCount: int
        :param OfflineCount: 离线个数
        :type OfflineCount: int
        :param State: 上报状态:
1: 正常上报
2: 异常上报
注：此处异常上报是指本次上报由于场内服务内部原因导致上报数据不可信等。此时离线个数重置为1，在线个数重置为0
        :type State: int
        """
        self.ServerIp = None
        self.ProgramName = None
        self.OnlineCount = None
        self.OfflineCount = None
        self.State = None


    def _deserialize(self, params):
        self.ServerIp = params.get("ServerIp")
        self.ProgramName = params.get("ProgramName")
        self.OnlineCount = params.get("OnlineCount")
        self.OfflineCount = params.get("OfflineCount")
        self.State = params.get("State")


class ReportServiceRegisterRequest(AbstractModel):
    """ReportServiceRegister请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param ServiceRegisterInfos: 服务上报当前的服务能力信息
        :type ServiceRegisterInfos: list of ServiceRegisterInfo
        :param ServerIp: 服务内网Ip
        :type ServerIp: str
        :param ServerNodeId: 上报服务所在服务器的唯一ID
        :type ServerNodeId: str
        :param ReportTime: 上报时间戳, 单位毫秒
        :type ReportTime: int
        """
        self.GroupCode = None
        self.MallId = None
        self.ServiceRegisterInfos = None
        self.ServerIp = None
        self.ServerNodeId = None
        self.ReportTime = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        if params.get("ServiceRegisterInfos") is not None:
            self.ServiceRegisterInfos = []
            for item in params.get("ServiceRegisterInfos"):
                obj = ServiceRegisterInfo()
                obj._deserialize(item)
                self.ServiceRegisterInfos.append(obj)
        self.ServerIp = params.get("ServerIp")
        self.ServerNodeId = params.get("ServerNodeId")
        self.ReportTime = params.get("ReportTime")


class ReportServiceRegisterResponse(AbstractModel):
    """ReportServiceRegister返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class SearchImageRequest(AbstractModel):
    """SearchImage请求参数结构体

    """

    def __init__(self):
        """
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param Image: 图片base64字符串
        :type Image: str
        :param ImageTime: 时间戳，毫秒
        :type ImageTime: int
        """
        self.GroupCode = None
        self.MallId = None
        self.Image = None
        self.ImageTime = None


    def _deserialize(self, params):
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        self.Image = params.get("Image")
        self.ImageTime = params.get("ImageTime")


class SearchImageResponse(AbstractModel):
    """SearchImage返回参数结构体

    """

    def __init__(self):
        """
        :param FaceId: face id
        :type FaceId: str
        :param Results: 搜索结果列表
        :type Results: list of SearchResult
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.FaceId = None
        self.Results = None
        self.RequestId = None


    def _deserialize(self, params):
        self.FaceId = params.get("FaceId")
        if params.get("Results") is not None:
            self.Results = []
            for item in params.get("Results"):
                obj = SearchResult()
                obj._deserialize(item)
                self.Results.append(obj)
        self.RequestId = params.get("RequestId")


class SearchResult(AbstractModel):
    """以图搜图检索结果

    """

    def __init__(self):
        """
        :param Image: 图片base64数据
        :type Image: str
        :param PersonId: 身份ID
        :type PersonId: str
        :param Similarity: 相似度
        :type Similarity: float
        """
        self.Image = None
        self.PersonId = None
        self.Similarity = None


    def _deserialize(self, params):
        self.Image = params.get("Image")
        self.PersonId = params.get("PersonId")
        self.Similarity = params.get("Similarity")


class ServerStateItem(AbstractModel):
    """服务器监控状态上报项

    """

    def __init__(self):
        """
        :param ServerState: 服务器状态
1: 在线
2: 离线
3: 重启
        :type ServerState: int
        :param ServerIp: 服务器IP
        :type ServerIp: str
        :param DiskInfos: 硬盘监控信息列表
        :type DiskInfos: list of DiskInfo
        """
        self.ServerState = None
        self.ServerIp = None
        self.DiskInfos = None


    def _deserialize(self, params):
        self.ServerState = params.get("ServerState")
        self.ServerIp = params.get("ServerIp")
        if params.get("DiskInfos") is not None:
            self.DiskInfos = []
            for item in params.get("DiskInfos"):
                obj = DiskInfo()
                obj._deserialize(item)
                self.DiskInfos.append(obj)


class ServiceRegisterInfo(AbstractModel):
    """用于服务注册时表示当前服务的具体信息

    """

    def __init__(self):
        """
        :param CgiUrl: 当前服务的回调地址
        :type CgiUrl: str
        :param ServiceType: 当前服务类型:
1: 多经服务
2: 相机误报警确认
3: 底图更新
        :type ServiceType: int
        """
        self.CgiUrl = None
        self.ServiceType = None


    def _deserialize(self, params):
        self.CgiUrl = params.get("CgiUrl")
        self.ServiceType = params.get("ServiceType")


class Task(AbstractModel):
    """任务信息

    """

    def __init__(self):
        """
        :param TaskId: 任务ID
        :type TaskId: int
        :param GroupCode: 集团编码
        :type GroupCode: str
        :param MallId: 广场ID
        :type MallId: int
        :param TaskContent: 任务内容
        :type TaskContent: :class:`tencentcloud.ump.v20200918.models.TaskContent`
        :param TaskType: 任务类型:
1: 底图拉取
        :type TaskType: int
        """
        self.TaskId = None
        self.GroupCode = None
        self.MallId = None
        self.TaskContent = None
        self.TaskType = None


    def _deserialize(self, params):
        self.TaskId = params.get("TaskId")
        self.GroupCode = params.get("GroupCode")
        self.MallId = params.get("MallId")
        if params.get("TaskContent") is not None:
            self.TaskContent = TaskContent()
            self.TaskContent._deserialize(params.get("TaskContent"))
        self.TaskType = params.get("TaskType")


class TaskContent(AbstractModel):
    """任务内容

    """

    def __init__(self):
        """
        :param CameraId: 摄像头ID
        :type CameraId: int
        :param RTSP: rtsp 地址
        :type RTSP: str
        :param Url: 图片上传地址
        :type Url: str
        """
        self.CameraId = None
        self.RTSP = None
        self.Url = None


    def _deserialize(self, params):
        self.CameraId = params.get("CameraId")
        self.RTSP = params.get("RTSP")
        self.Url = params.get("Url")


class ZoneArea(AbstractModel):
    """点位包含店门标注

    """

    def __init__(self):
        """
        :param ZoneId: 点位ID
        :type ZoneId: int
        :param ShopArea: 店门标注
        :type ShopArea: list of Point
        """
        self.ZoneId = None
        self.ShopArea = None


    def _deserialize(self, params):
        self.ZoneId = params.get("ZoneId")
        if params.get("ShopArea") is not None:
            self.ShopArea = []
            for item in params.get("ShopArea"):
                obj = Point()
                obj._deserialize(item)
                self.ShopArea.append(obj)


class ZoneConfig(AbstractModel):
    """点位包含绑定、调试信息

    """

    def __init__(self):
        """
        :param ZoneId: 点位ID
        :type ZoneId: int
        :param ZoneName: 点位名称
        :type ZoneName: str
        :param ZoneType: 点位类型:
1: 场门
3: 层门
5: 特殊区域
7: 门店
8: 补位
10: 开放式门店
11: 品类区
12: 公共区
        :type ZoneType: int
        :param BunkCodes: 铺位编码
        :type BunkCodes: str
        :param FloorName: 楼层名称
        :type FloorName: str
        :param FloorId: 楼层ID
        :type FloorId: int
        :param BindNum: 绑定数
        :type BindNum: int
        :param DebugNum: 调试数
        :type DebugNum: int
        :param State: 下发状态:
1: 不可下发
2: 可下发
3: 已下发
        :type State: int
        """
        self.ZoneId = None
        self.ZoneName = None
        self.ZoneType = None
        self.BunkCodes = None
        self.FloorName = None
        self.FloorId = None
        self.BindNum = None
        self.DebugNum = None
        self.State = None


    def _deserialize(self, params):
        self.ZoneId = params.get("ZoneId")
        self.ZoneName = params.get("ZoneName")
        self.ZoneType = params.get("ZoneType")
        self.BunkCodes = params.get("BunkCodes")
        self.FloorName = params.get("FloorName")
        self.FloorId = params.get("FloorId")
        self.BindNum = params.get("BindNum")
        self.DebugNum = params.get("DebugNum")
        self.State = params.get("State")


# -*- coding: utf8 -*-
# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from tencentcloud.common.abstract_model import AbstractModel


class BeautifyPicRequest(AbstractModel):
    """BeautifyPic请求参数结构体

    """

    def __init__(self):
        """
        :param Image: 图片 base64 数据，base64 编码后大小不可超过5M。 
支持PNG、JPG、JPEG、BMP，不支持 GIF 图片。
        :type Image: str
        :param Url: 图片的 Url 。对应图片 base64 编码后大小不可超过5M。 
Url、Image必须提供一个，如果都提供，只使用 Url。  
图片存储于腾讯云的Url可保障更高下载速度和稳定性，建议图片存储于腾讯云。  
非腾讯云存储的Url速度和稳定性可能受一定影响。 
支持PNG、JPG、JPEG、BMP，不支持 GIF 图片。
        :type Url: str
        :param Whitening: 美白程度，取值范围[0,100]。0不美白，100代表最高程度。默认值30。
        :type Whitening: int
        :param Smoothing: 磨皮程度，取值范围[0,100]。0不磨皮，100代表最高程度。默认值10。
        :type Smoothing: int
        :param FaceLifting: 瘦脸程度，取值范围[0,100]。0不瘦脸，100代表最高程度。默认值70。
        :type FaceLifting: int
        :param EyeEnlarging: 大眼程度，取值范围[0,100]。0不大眼，100代表最高程度。默认值70。
        :type EyeEnlarging: int
        :param RspImgType: 返回图像方式（base64 或 url ) ，二选一。url有效期为1天。
        :type RspImgType: str
        """
        self.Image = None
        self.Url = None
        self.Whitening = None
        self.Smoothing = None
        self.FaceLifting = None
        self.EyeEnlarging = None
        self.RspImgType = None


    def _deserialize(self, params):
        self.Image = params.get("Image")
        self.Url = params.get("Url")
        self.Whitening = params.get("Whitening")
        self.Smoothing = params.get("Smoothing")
        self.FaceLifting = params.get("FaceLifting")
        self.EyeEnlarging = params.get("EyeEnlarging")
        self.RspImgType = params.get("RspImgType")


class BeautifyPicResponse(AbstractModel):
    """BeautifyPic返回参数结构体

    """

    def __init__(self):
        """
        :param ResultImage: RspImgType 为 base64 时，返回处理后的图片 base64 数据。默认返回base64
        :type ResultImage: str
        :param ResultUrl: RspImgType 为 url 时，返回处理后的图片 url 数据。
        :type ResultUrl: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.ResultImage = None
        self.ResultUrl = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ResultImage = params.get("ResultImage")
        self.ResultUrl = params.get("ResultUrl")
        self.RequestId = params.get("RequestId")


class BeautifyVideoOutput(AbstractModel):
    """视频美颜返回结果

    """

    def __init__(self):
        """
        :param VideoUrl: 视频美颜输出的url
注意：此字段可能返回 null，表示取不到有效值。
        :type VideoUrl: str
        :param VideoMD5: 视频美颜输出的视频MD5，用于校验
注意：此字段可能返回 null，表示取不到有效值。
        :type VideoMD5: str
        :param CoverImage: 美颜输出的视频封面图base64字符串
注意：此字段可能返回 null，表示取不到有效值。
        :type CoverImage: str
        :param Width: 视频宽度
注意：此字段可能返回 null，表示取不到有效值。
        :type Width: int
        :param Height: 视频高度
注意：此字段可能返回 null，表示取不到有效值。
        :type Height: int
        :param Fps: 每秒传输帧数
注意：此字段可能返回 null，表示取不到有效值。
        :type Fps: float
        :param DurationInSec: 视频播放时长，单位为秒
注意：此字段可能返回 null，表示取不到有效值。
        :type DurationInSec: float
        """
        self.VideoUrl = None
        self.VideoMD5 = None
        self.CoverImage = None
        self.Width = None
        self.Height = None
        self.Fps = None
        self.DurationInSec = None


    def _deserialize(self, params):
        self.VideoUrl = params.get("VideoUrl")
        self.VideoMD5 = params.get("VideoMD5")
        self.CoverImage = params.get("CoverImage")
        self.Width = params.get("Width")
        self.Height = params.get("Height")
        self.Fps = params.get("Fps")
        self.DurationInSec = params.get("DurationInSec")


class BeautifyVideoRequest(AbstractModel):
    """BeautifyVideo请求参数结构体

    """

    def __init__(self):
        """
        :param Url: 视频url地址
        :type Url: str
        :param BeautyParam: 美颜参数 - 美白、平滑、大眼和瘦脸。参数值范围[0, 100]。参数值为0，则不做美颜。参数默认值为0。目前默认取数组第一个元素是对所有人脸美颜。
        :type BeautyParam: list of BeautyParam
        :param OutputVideoType: 目前只支持mp4
        :type OutputVideoType: str
        """
        self.Url = None
        self.BeautyParam = None
        self.OutputVideoType = None


    def _deserialize(self, params):
        self.Url = params.get("Url")
        if params.get("BeautyParam") is not None:
            self.BeautyParam = []
            for item in params.get("BeautyParam"):
                obj = BeautyParam()
                obj._deserialize(item)
                self.BeautyParam.append(obj)
        self.OutputVideoType = params.get("OutputVideoType")


class BeautifyVideoResponse(AbstractModel):
    """BeautifyVideo返回参数结构体

    """

    def __init__(self):
        """
        :param JobId: 视频美颜任务的Job id
        :type JobId: str
        :param EstimatedProcessTime: 预估处理时间，粒度为秒
        :type EstimatedProcessTime: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.JobId = None
        self.EstimatedProcessTime = None
        self.RequestId = None


    def _deserialize(self, params):
        self.JobId = params.get("JobId")
        self.EstimatedProcessTime = params.get("EstimatedProcessTime")
        self.RequestId = params.get("RequestId")


class BeautyParam(AbstractModel):
    """全局美颜参数，针对所有人脸做美颜。参数全部为0，则为不做美颜

    """

    def __init__(self):
        """
        :param WhitenLevel: 美白程度，取值范围[0,100]。0不美白，100代表最高程度。默认值30。
        :type WhitenLevel: int
        :param SmoothingLevel: 磨皮程度，取值范围[0,100]。0不磨皮，100代表最高程度。默认值30。
        :type SmoothingLevel: int
        :param EyeEnlargeLevel: 大眼程度，取值范围[0,100]。0不大眼，100代表最高程度。默认值70。
        :type EyeEnlargeLevel: int
        :param FaceShrinkLevel: 瘦脸程度，取值范围[0,100]。0不瘦脸，100代表最高程度。默认值70。
        :type FaceShrinkLevel: int
        """
        self.WhitenLevel = None
        self.SmoothingLevel = None
        self.EyeEnlargeLevel = None
        self.FaceShrinkLevel = None


    def _deserialize(self, params):
        self.WhitenLevel = params.get("WhitenLevel")
        self.SmoothingLevel = params.get("SmoothingLevel")
        self.EyeEnlargeLevel = params.get("EyeEnlargeLevel")
        self.FaceShrinkLevel = params.get("FaceShrinkLevel")


class CancelBeautifyVideoJobRequest(AbstractModel):
    """CancelBeautifyVideoJob请求参数结构体

    """

    def __init__(self):
        """
        :param JobId: 美颜视频的Job id
        :type JobId: str
        """
        self.JobId = None


    def _deserialize(self, params):
        self.JobId = params.get("JobId")


class CancelBeautifyVideoJobResponse(AbstractModel):
    """CancelBeautifyVideoJob返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class CreateModelRequest(AbstractModel):
    """CreateModel请求参数结构体

    """

    def __init__(self):
        """
        :param LUTFile: 图片base64数据，用于试唇色，要求必须是LUT 格式的cube文件转换成512*512的PNG图片。查看 [LUT文件的使用说明](https://cloud.tencent.com/document/product/1172/41701)。了解 [cube文件转png图片小工具](http://yyb.gtimg.com/aiplat/static/qcloud-cube-to-png.html)。
        :type LUTFile: str
        :param Description: 文件描述信息，可用于备注。
        :type Description: str
        """
        self.LUTFile = None
        self.Description = None


    def _deserialize(self, params):
        self.LUTFile = params.get("LUTFile")
        self.Description = params.get("Description")


class CreateModelResponse(AbstractModel):
    """CreateModel返回参数结构体

    """

    def __init__(self):
        """
        :param ModelId: 唇色素材ID。
        :type ModelId: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.ModelId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ModelId = params.get("ModelId")
        self.RequestId = params.get("RequestId")


class DeleteModelRequest(AbstractModel):
    """DeleteModel请求参数结构体

    """

    def __init__(self):
        """
        :param ModelId: 素材ID。
        :type ModelId: str
        """
        self.ModelId = None


    def _deserialize(self, params):
        self.ModelId = params.get("ModelId")


class DeleteModelResponse(AbstractModel):
    """DeleteModel返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class FaceRect(AbstractModel):
    """人脸框信息

    """

    def __init__(self):
        """
        :param X: 人脸框左上角横坐标。
        :type X: int
        :param Y: 人脸框左上角纵坐标。
        :type Y: int
        :param Width: 人脸框宽度。
        :type Width: int
        :param Height: 人脸框高度。
        :type Height: int
        """
        self.X = None
        self.Y = None
        self.Width = None
        self.Height = None


    def _deserialize(self, params):
        self.X = params.get("X")
        self.Y = params.get("Y")
        self.Width = params.get("Width")
        self.Height = params.get("Height")


class GetModelListRequest(AbstractModel):
    """GetModelList请求参数结构体

    """

    def __init__(self):
        """
        :param Offset: 起始序号，默认值为0。
        :type Offset: int
        :param Limit: 返回数量，默认值为10，最大值为100。
        :type Limit: int
        """
        self.Offset = None
        self.Limit = None


    def _deserialize(self, params):
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")


class GetModelListResponse(AbstractModel):
    """GetModelList返回参数结构体

    """

    def __init__(self):
        """
        :param ModelIdNum: 唇色素材总数量。
        :type ModelIdNum: int
        :param ModelInfos: 素材数据
注意：此字段可能返回 null，表示取不到有效值。
        :type ModelInfos: list of ModelInfo
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.ModelIdNum = None
        self.ModelInfos = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ModelIdNum = params.get("ModelIdNum")
        if params.get("ModelInfos") is not None:
            self.ModelInfos = []
            for item in params.get("ModelInfos"):
                obj = ModelInfo()
                obj._deserialize(item)
                self.ModelInfos.append(obj)
        self.RequestId = params.get("RequestId")


class LipColorInfo(AbstractModel):
    """唇色信息

    """

    def __init__(self):
        """
        :param RGBA: 使用RGBA模型试唇色。
        :type RGBA: :class:`tencentcloud.fmu.v20191213.models.RGBAInfo`
        :param ModelId: 使用已注册的 LUT 文件试唇色。  
ModelId 和 RGBA 两个参数只需提供一个，若都提供只使用 ModelId。
        :type ModelId: str
        :param FaceRect: 人脸框位置。若不输入则选择 Image 或 Url 中面积最大的人脸。  
您可以通过 [人脸检测与分析](https://cloud.tencent.com/document/api/867/32800)  接口获取人脸框位置信息。
        :type FaceRect: :class:`tencentcloud.fmu.v20191213.models.FaceRect`
        :param ModelAlpha: 涂妆浓淡[0,100]。建议取值50。本参数仅控制ModelId对应的涂妆浓淡。
        :type ModelAlpha: int
        """
        self.RGBA = None
        self.ModelId = None
        self.FaceRect = None
        self.ModelAlpha = None


    def _deserialize(self, params):
        if params.get("RGBA") is not None:
            self.RGBA = RGBAInfo()
            self.RGBA._deserialize(params.get("RGBA"))
        self.ModelId = params.get("ModelId")
        if params.get("FaceRect") is not None:
            self.FaceRect = FaceRect()
            self.FaceRect._deserialize(params.get("FaceRect"))
        self.ModelAlpha = params.get("ModelAlpha")


class ModelInfo(AbstractModel):
    """LUT素材信息

    """

    def __init__(self):
        """
        :param ModelId: 唇色素材ID
        :type ModelId: str
        :param LUTFileUrl: 唇色素材 url 。 LUT 文件 url 5分钟有效。
        :type LUTFileUrl: str
        :param Description: 文件描述信息。
        :type Description: str
        """
        self.ModelId = None
        self.LUTFileUrl = None
        self.Description = None


    def _deserialize(self, params):
        self.ModelId = params.get("ModelId")
        self.LUTFileUrl = params.get("LUTFileUrl")
        self.Description = params.get("Description")


class QueryBeautifyVideoJobRequest(AbstractModel):
    """QueryBeautifyVideoJob请求参数结构体

    """

    def __init__(self):
        """
        :param JobId: 视频美颜Job id
        :type JobId: str
        """
        self.JobId = None


    def _deserialize(self, params):
        self.JobId = params.get("JobId")


class QueryBeautifyVideoJobResponse(AbstractModel):
    """QueryBeautifyVideoJob返回参数结构体

    """

    def __init__(self):
        """
        :param JobStatus: 当前任务状态：排队中、处理中、处理失败或者处理完成
        :type JobStatus: str
        :param BeautifyVideoOutput: 视频美颜输出的结果信息
注意：此字段可能返回 null，表示取不到有效值。
        :type BeautifyVideoOutput: :class:`tencentcloud.fmu.v20191213.models.BeautifyVideoOutput`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.JobStatus = None
        self.BeautifyVideoOutput = None
        self.RequestId = None


    def _deserialize(self, params):
        self.JobStatus = params.get("JobStatus")
        if params.get("BeautifyVideoOutput") is not None:
            self.BeautifyVideoOutput = BeautifyVideoOutput()
            self.BeautifyVideoOutput._deserialize(params.get("BeautifyVideoOutput"))
        self.RequestId = params.get("RequestId")


class RGBAInfo(AbstractModel):
    """RGBA通道信息

    """

    def __init__(self):
        """
        :param R: R通道数值。[0,255]。
        :type R: int
        :param G: G通道数值。[0,255]。
        :type G: int
        :param B: B通道数值。[0,255]。
        :type B: int
        :param A: A通道数值。[0,100]。建议取值50。
        :type A: int
        """
        self.R = None
        self.G = None
        self.B = None
        self.A = None


    def _deserialize(self, params):
        self.R = params.get("R")
        self.G = params.get("G")
        self.B = params.get("B")
        self.A = params.get("A")


class StyleImageProRequest(AbstractModel):
    """StyleImagePro请求参数结构体

    """

    def __init__(self):
        """
        :param FilterType: 滤镜类型，取值如下： 
1.白茶；2 白皙；3.初夏；4.东京；5.告白；6.暖阳；7.蔷薇；8.清澄；9.清透；10.甜薄荷；11.默认；12.心动；13.哑灰；14.樱桃布丁；15.自然；16.清逸；17.黑白；18.水果；19.爱情；20.冬日；21.相片；22.夏日；23.香氛；24.魅惑；25.悸动；26.沙滩；27.街拍；28.甜美；29.初吻；30.午后；31.活力；32.朦胧；33.悦动；34.时尚；35.气泡；36.柠檬；37.棉花糖；38.小溪；39.丽人；40.咖啡；41.嫩芽；42.热情；43.渐暖；44.早餐；45.白茶；46.白嫩；47.圣代；48.森林；49.冲浪；50.奶咖；51.清澈；52.微风；53.日落；54.水光；55.日系；56.星光；57.阳光；58.落叶；59.生机；60.甜心；61.清逸；62.春意；63.罗马；64.青涩；65.清风；66.暖心；67.海水；68.神秘；69.旧调1；70.旧调2；71.雪顶；72.日光；73.浮云；74.流彩；75.胶片；76.回味；77.奶酪；78.蝴蝶。
        :type FilterType: int
        :param Image: 图片 base64 数据，base64 编码后大小不可超过5M。 
支持PNG、JPG、JPEG、BMP，不支持 GIF 图片。
        :type Image: str
        :param Url: 图片的 Url ，对应图片 base64 编码后大小不可超过5M。 
图片的 Url、Image必须提供一个，如果都提供，只使用 Url。  
图片存储于腾讯云的 Url 可保障更高下载速度和稳定性，建议图片存储于腾讯云。  
非腾讯云存储的Url速度和稳定性可能受一定影响。  
支持PNG、JPG、JPEG、BMP 等图片格式，不支持 GIF 图片。
        :type Url: str
        :param FilterDegree: 滤镜效果，取值[0,100]，0表示无效果，100表示满滤镜效果。默认值为80。
        :type FilterDegree: int
        :param RspImgType: 返回图像方式（base64 或 url ) ，二选一。url有效期为1天。
        :type RspImgType: str
        """
        self.FilterType = None
        self.Image = None
        self.Url = None
        self.FilterDegree = None
        self.RspImgType = None


    def _deserialize(self, params):
        self.FilterType = params.get("FilterType")
        self.Image = params.get("Image")
        self.Url = params.get("Url")
        self.FilterDegree = params.get("FilterDegree")
        self.RspImgType = params.get("RspImgType")


class StyleImageProResponse(AbstractModel):
    """StyleImagePro返回参数结构体

    """

    def __init__(self):
        """
        :param ResultImage: RspImgType 为 base64 时，返回处理后的图片 base64 数据。默认返回base64
注意：此字段可能返回 null，表示取不到有效值。
        :type ResultImage: str
        :param ResultUrl: RspImgType 为 url 时，返回处理后的图片 url 数据。
注意：此字段可能返回 null，表示取不到有效值。
        :type ResultUrl: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.ResultImage = None
        self.ResultUrl = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ResultImage = params.get("ResultImage")
        self.ResultUrl = params.get("ResultUrl")
        self.RequestId = params.get("RequestId")


class StyleImageRequest(AbstractModel):
    """StyleImage请求参数结构体

    """

    def __init__(self):
        """
        :param FilterType: 滤镜类型，取值如下： 
1.白茶；2 白皙；3.初夏；4.东京；5.告白；6.暖阳；7.蔷薇；8.清澄；9.清透；10.甜薄荷；11.默认；12.心动；13.哑灰；14.樱桃布丁；15.自然；16.清逸；17.黑白；18.水果；19.爱情；20.冬日；21.相片；22.夏日；23.香氛；24.魅惑；25.悸动；26.沙滩；27.街拍；28.甜美；29.初吻；30.午后。
        :type FilterType: int
        :param Image: 图片 base64 数据，base64 编码后大小不可超过5M。 
支持PNG、JPG、JPEG、BMP，不支持 GIF 图片。
        :type Image: str
        :param Url: 图片的 Url ，对应图片 base64 编码后大小不可超过5M。 
图片的 Url、Image必须提供一个，如果都提供，只使用 Url。  
图片存储于腾讯云的 Url 可保障更高下载速度和稳定性，建议图片存储于腾讯云。  
非腾讯云存储的Url速度和稳定性可能受一定影响。  
支持PNG、JPG、JPEG、BMP 等图片格式，不支持 GIF 图片。
        :type Url: str
        :param FilterDegree: 滤镜效果，取值[0,100]，0表示无效果，100表示满滤镜效果。默认值为80。
        :type FilterDegree: int
        :param RspImgType: 返回图像方式（base64 或 url ) ，二选一。url有效期为1天。
        :type RspImgType: str
        """
        self.FilterType = None
        self.Image = None
        self.Url = None
        self.FilterDegree = None
        self.RspImgType = None


    def _deserialize(self, params):
        self.FilterType = params.get("FilterType")
        self.Image = params.get("Image")
        self.Url = params.get("Url")
        self.FilterDegree = params.get("FilterDegree")
        self.RspImgType = params.get("RspImgType")


class StyleImageResponse(AbstractModel):
    """StyleImage返回参数结构体

    """

    def __init__(self):
        """
        :param ResultImage: RspImgType 为 base64 时，返回处理后的图片 base64 数据。默认返回base64
注意：此字段可能返回 null，表示取不到有效值。
        :type ResultImage: str
        :param ResultUrl: RspImgType 为 url 时，返回处理后的图片 url 数据。
注意：此字段可能返回 null，表示取不到有效值。
        :type ResultUrl: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.ResultImage = None
        self.ResultUrl = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ResultImage = params.get("ResultImage")
        self.ResultUrl = params.get("ResultUrl")
        self.RequestId = params.get("RequestId")


class TryLipstickPicRequest(AbstractModel):
    """TryLipstickPic请求参数结构体

    """

    def __init__(self):
        """
        :param LipColorInfos: 唇色信息。 
您可以输入最多3个 LipColorInfo 来实现给一张图中的最多3张人脸试唇色。
        :type LipColorInfos: list of LipColorInfo
        :param Image: 图片 base64 数据，base64 编码后大小不可超过6M。 
支持PNG、JPG、JPEG、BMP，不支持 GIF 图片。
        :type Image: str
        :param Url: 图片的 Url ，对应图片 base64 编码后大小不可超过6M。 
图片的 Url、Image必须提供一个，如果都提供，只使用 Url。 
图片存储于腾讯云的 Url 可保障更高下载速度和稳定性，建议图片存储于腾讯云。 
非腾讯云存储的Url速度和稳定性可能受一定影响。 
支持PNG、JPG、JPEG、BMP，不支持 GIF 图片。
        :type Url: str
        :param RspImgType: 返回图像方式（base64 或 url ) ，二选一。url有效期为1天。
        :type RspImgType: str
        """
        self.LipColorInfos = None
        self.Image = None
        self.Url = None
        self.RspImgType = None


    def _deserialize(self, params):
        if params.get("LipColorInfos") is not None:
            self.LipColorInfos = []
            for item in params.get("LipColorInfos"):
                obj = LipColorInfo()
                obj._deserialize(item)
                self.LipColorInfos.append(obj)
        self.Image = params.get("Image")
        self.Url = params.get("Url")
        self.RspImgType = params.get("RspImgType")


class TryLipstickPicResponse(AbstractModel):
    """TryLipstickPic返回参数结构体

    """

    def __init__(self):
        """
        :param ResultImage: RspImgType 为 base64 时，返回处理后的图片 base64 数据。默认返回base64
        :type ResultImage: str
        :param ResultUrl: RspImgType 为 url 时，返回处理后的图片 url 数据。
        :type ResultUrl: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.ResultImage = None
        self.ResultUrl = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ResultImage = params.get("ResultImage")
        self.ResultUrl = params.get("ResultUrl")
        self.RequestId = params.get("RequestId")


# -*- coding: utf8 -*-
# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from tencentcloud.common.abstract_model import AbstractModel


class AgentShell(AbstractModel):
    """agent安装脚本串

    """

    def __init__(self):
        """
        :param Token: 鉴权token
注意：此字段可能返回 null，表示取不到有效值。
        :type Token: str
        :param EtlIp: 数据接收Ip
注意：此字段可能返回 null，表示取不到有效值。
        :type EtlIp: str
        :param EtlPort: 数据接收port
注意：此字段可能返回 null，表示取不到有效值。
        :type EtlPort: str
        :param ByHandAccess: 手动接入脚本串
注意：此字段可能返回 null，表示取不到有效值。
        :type ByHandAccess: str
        :param ByShellAccess: 自动接入脚本串
注意：此字段可能返回 null，表示取不到有效值。
        :type ByShellAccess: str
        :param SkyWalkingPort: SkyWalking数据接收port
注意：此字段可能返回 null，表示取不到有效值。
        :type SkyWalkingPort: str
        :param ZipkinPort: Zipkin数据接收port
注意：此字段可能返回 null，表示取不到有效值。
        :type ZipkinPort: str
        :param JaegerPort: Jaeger数据接收port
注意：此字段可能返回 null，表示取不到有效值。
        :type JaegerPort: str
        """
        self.Token = None
        self.EtlIp = None
        self.EtlPort = None
        self.ByHandAccess = None
        self.ByShellAccess = None
        self.SkyWalkingPort = None
        self.ZipkinPort = None
        self.JaegerPort = None


    def _deserialize(self, params):
        self.Token = params.get("Token")
        self.EtlIp = params.get("EtlIp")
        self.EtlPort = params.get("EtlPort")
        self.ByHandAccess = params.get("ByHandAccess")
        self.ByShellAccess = params.get("ByShellAccess")
        self.SkyWalkingPort = params.get("SkyWalkingPort")
        self.ZipkinPort = params.get("ZipkinPort")
        self.JaegerPort = params.get("JaegerPort")


class DescribeAgentShellRequest(AbstractModel):
    """DescribeAgentShell请求参数结构体

    """


class DescribeAgentShellResponse(AbstractModel):
    """DescribeAgentShell返回参数结构体

    """

    def __init__(self):
        """
        :param Result: 接入信息
注意：此字段可能返回 null，表示取不到有效值。
        :type Result: :class:`tencentcloud.tsw.v20200924.models.AgentShell`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Result = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Result") is not None:
            self.Result = AgentShell()
            self.Result._deserialize(params.get("Result"))
        self.RequestId = params.get("RequestId")